Files
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

65 lines
2.0 KiB
C++

/* Copyright (c) Advanced Micro Devices, Inc. All rights reserved.
*
* SPDX-License-Identifier: MIT
*/
#include "hipfile-warnings.h"
#include "hipfile.h"
#include "test-common.h"
#include "test-shared-fixtures.h"
#include <cstdint>
#include <gtest/gtest.h>
#include <hip/hip_runtime_api.h>
#include <memory>
HIPFILE_WARN_NO_GLOBAL_CTOR_OFF
class HipBuffer : public DriverInit {};
TEST_F(HipBuffer, hipFileBufRegisterWithDeviceMemoryIsSuccessful)
{
void *device_ptr;
ASSERT_EQ(hipMalloc(&device_ptr, 4096), hipSuccess);
ASSERT_EQ(hipFileBufRegister(device_ptr, 4096, 0), HIPFILE_SUCCESS);
}
TEST_F(HipBuffer, hipFileBufRegisterWithOffsetDeviceMemoryIsSuccessful)
{
void *device_ptr;
ASSERT_EQ(hipMalloc(&device_ptr, 8192), hipSuccess);
ASSERT_EQ(hipFileBufRegister(reinterpret_cast<void *>((reinterpret_cast<uintptr_t>(device_ptr) + 4096)),
4096, 0),
HIPFILE_SUCCESS);
}
TEST_F(HipBuffer, hipFileBufRegisterWithOversizeLengthErrors)
{
void *device_ptr;
ASSERT_EQ(hipMalloc(&device_ptr, 4096), hipSuccess);
ASSERT_EQ(hipFileBufRegister(device_ptr, 8192, 0), HipFileOpError(hipFileHipPointerRangeError));
}
TEST_F(HipBuffer, hipFileBufRegisterWithOffsetPointerAndOversizeLengthErrors)
{
void *device_ptr;
ASSERT_EQ(hipMalloc(&device_ptr, 8192), hipSuccess);
ASSERT_EQ(hipFileBufRegister(reinterpret_cast<void *>((reinterpret_cast<uintptr_t>(device_ptr) + 4096)),
8192, 0),
HipFileOpError(hipFileHipPointerRangeError));
}
TEST_F(HipBuffer, hipFileBufRegisterWithOverflowLengthErrors)
{
void *device_ptr;
ASSERT_EQ(hipMalloc(&device_ptr, 4096), hipSuccess);
ASSERT_EQ(hipFileBufRegister(device_ptr, UINT64_MAX, 0), HipFileOpError(hipFileHipPointerRangeError));
}
TEST_F(HipBuffer, hipFileBufRegisterWithNullptrErrors)
{
ASSERT_EQ(hipFileBufRegister(nullptr, 8192, 0), HipFileOpError(hipFileInvalidValue));
}
HIPFILE_WARN_NO_GLOBAL_CTOR_ON